Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(449)

Unified Diff: services/ui/ws/display.h

Issue 2712203002: c++ / mojo changes for 'external window mode'
Patch Set: addressed sky/fwang/kylechar feedback (take 6), simpler mus_demo changes / passing unittests Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: services/ui/ws/display.h
diff --git a/services/ui/ws/display.h b/services/ui/ws/display.h
index 478f16a37a93e48de6cf96cb6940865af3e22bd2..f1d28f36e05b77aea94a675b2273fb8cd0188a3b 100644
--- a/services/ui/ws/display.h
+++ b/services/ui/ws/display.h
@@ -153,7 +153,11 @@ class Display : public PlatformDisplayDelegate,
using WindowManagerDisplayRootMap =
std::map<UserId, WindowManagerDisplayRoot*>;
- // Inits the necessary state once the display is ready.
+ // Inits the display root once the display is ready in
+ // 'external window mode'.
+ void InitDisplayRoot();
+
+ // Inits the necessary WindowManager state once the display is ready.
void InitWindowManagerDisplayRoots();
// Creates the set of WindowManagerDisplayRoots from the
@@ -207,6 +211,8 @@ class Display : public PlatformDisplayDelegate,
WindowManagerDisplayRootMap window_manager_display_root_map_;
+ std::unique_ptr<WindowManagerDisplayRoot> external_mode_root_;
+
DISALLOW_COPY_AND_ASSIGN(Display);
};

Powered by Google App Engine
This is Rietveld 408576698